==> jruby1.0_1.0.2.orig.tar.gz: jruby-1.0.2/src/org/jruby/lexer/yacc/SimplePositionFactory.java <==
/*
 * **** BEGIN LICENSE BLOCK *****
 * Version: CPL 1.0/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Common Public
 * License Version 1.0 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.eclipse.org/legal/cpl-v10.html
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * Copyright (C) 2007 Thomas E Enebo <enebo@acm.org>
 * 
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the CPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the CPL, the GPL or the LGPL.
 ***** END LICENSE BLOCK *****/
package org.jruby.lexer.yacc;

public class SimplePositionFactory implements ISourcePositionFactory {
    private LexerSource source;
    private ISourcePosition lastPosition;

    public SimplePositionFactory(LexerSource source, int line) {
        this.source = source;
        lastPosition = new SimpleSourcePosition(source.getFilename(), line);
    }

    public ISourcePosition getPosition(ISourcePosition startPosition, boolean inclusive) {
        if (startPosition != null) {
            lastPosition = startPosition;
            
            return lastPosition;
        }

        if (lastPosition.getStartLine() == source.getLine()) {
            return lastPosition;
        }
        
        lastPosition = new SimpleSourcePosition(source.getFilename(), source.getLine());

        return lastPosition;
    }

}

==> jruby_1.5.6.orig.tar.gz: jruby-1.5.6/src/org/jruby/lexer/yacc/SimplePositionFactory.java <==
/*
 * **** BEGIN LICENSE BLOCK *****
 * Version: CPL 1.0/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Common Public
 * License Version 1.0 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.eclipse.org/legal/cpl-v10.html
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * Copyright (C) 2007 Thomas E Enebo <enebo@acm.org>
 * 
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the CPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the CPL, the GPL or the LGPL.
 ***** END LICENSE BLOCK *****/
package org.jruby.lexer.yacc;

public class SimplePositionFactory {
    private LexerSource source;
    private ISourcePosition lastPosition;

    public SimplePositionFactory(LexerSource source, int line) {
        this.source = source;
        lastPosition = new SimpleSourcePosition(source.getFilename(), line);
    }

    public ISourcePosition getPosition(ISourcePosition startPosition) {
        if (startPosition != null) {
            lastPosition = startPosition;
            
            return lastPosition;
        }

        return getPosition();
    }

    public ISourcePosition getPosition() {
        if (lastPosition.getStartLine() == source.getLine()) return lastPosition;

        lastPosition = new SimpleSourcePosition(source.getFilename(), source.getLine());

        return lastPosition;
    }
}
